@@ -397,12 +397,8 @@ void autostop(xcWidget w, caddr_t clientdata, caddr_t nulldata)
 #endif
 
 /*--------------------------------------------------------------*/
-/* Auto-scale the drawing to fit the declared page size.	*/
+/* Auto-scale							*/
 /* (for now, with fixed 1" margins)				*/
-/*								*/
-/* If the page is declared encapsulated, then do nothing.	*/
-/* If a frame box is on the page, then scale to fit the frame	*/
-/* to the declared page size, not the whole object.		*/
 /*--------------------------------------------------------------*/
 
 void autoscale(int page)
@@ -412,7 +408,6 @@ void autoscale(int page)
 	== CM) ? CMSCALE : INCHSCALE;
    float margin = 144.0;
    int width, height;
-   polyptr framebox;
 
    if (!(xobjs.pagelist[page]->pmode & 2)) return;
    else if (topobject->bbox.width == 0 || topobject->bbox.height == 0) {
@@ -425,25 +420,13 @@ void autoscale(int page)
    newyscale = (xobjs.pagelist[page]->pagesize.y - margin)
 	/ scalefudge;
 
-   if ((framebox = checkforbbox(topobject)) != NULL) {
-      int i, minx, miny, maxx, maxy;
-      
-      minx = maxx = framebox->points[0].x;
-      miny = maxy = framebox->points[0].y;
-      for (i = 1; i < framebox->number; i++) {
-	 if (framebox->points[i].x < minx) minx = framebox->points[i].x;
-	 else if (framebox->points[i].x > maxx) maxx = framebox->points[i].x;
-	 if (framebox->points[i].y < miny) miny = framebox->points[i].y;
-	 else if (framebox->points[i].y > maxy) maxy = framebox->points[i].y;
-      }
-      width = (maxx - minx);
-      height = (maxy - miny);
-   }
-   else {
-
-      width = toplevelwidth(areastruct.topinstance, NULL);
-      height = toplevelheight(areastruct.topinstance, NULL);
-   }
+#ifdef SCHEMA
+   width = toplevelwidth(areastruct.topinstance);
+   height = toplevelheight(areastruct.topinstance);
+#else
+   width = topobject->bbox.width;
+   height = topobject->bbox.height;
+#endif
 
    if (xobjs.pagelist[page]->orient == 0) {	/* Portrait */
       newxscale /= width;
@@ -453,6 +436,7 @@ void autoscale(int page)
       newxscale /= height;
       newyscale /= width;
    }
+
    xobjs.pagelist[page]->outscale = min(newxscale, newyscale);
 }
 
@@ -1043,9 +1027,11 @@ void setpagelabel(xcWidget w, char *dataptr)
    else
       sprintf(topobject->name, "%.79s", _STR2);
 
+#ifdef SCHEMA
    /* For schematics, all pages with associations to symbols must have	*/
    /* unique names.							*/
    if (topobject->symschem != NULL) checkpagename(topobject);
+#endif
 
    printname(topobject);
    renamepage(areastruct.page);
@@ -1123,8 +1109,7 @@ void makenewencodingbutton(char *ename, char value)
 
 void togglefontmark(int fontval)
 {
-   Tcl_SetVar2(xcinterp, "XCOps", "fontfamily", fonts[fontval].family,
-		TCL_NAMESPACE_ONLY);
+   Tcl_SetVar(xcinterp, "fontfamily", fonts[fontval].family, TCL_NAMESPACE_ONLY);
 }
 
 #else
@@ -1208,7 +1193,13 @@ void toggleexcl(xcWidget widget, menuptr menu, int menulength)
 /* Toggle a menu item */
 /*--------------------*/
 
-#ifndef TCL_WRAPPER
+#ifdef TCL_WRAPPER
+
+void toggle(xcWidget w, Boolean *boolvalue, caddr_t calldata)
+{
+}
+
+#else
 
 void toggle(xcWidget w, Boolean *boolvalue, caddr_t calldata)
 {
@@ -1300,7 +1291,7 @@ void togglegrid(u_short type)
    /* string; doing so prevents the menu from recognizing the variable	*/
    /* value.								*/
 
-   Tcl_SetVar2(xcinterp, "XCOps", "gridstyle", stylenames[type], TCL_NAMESPACE_ONLY);
+   Tcl_SetVar(xcinterp, "gridstyle", stylenames[type], TCL_NAMESPACE_ONLY);
 }
 
 #else
@@ -1546,15 +1537,12 @@ void makepagebutton()
 
 void renamepage(short pagenumber)
 {
-   int page;
-   objinstptr thisinst = xobjs.pagelist[pagenumber]->pageinst;
-
 #ifdef TCL_WRAPPER
    char *pname, *plabel;
 
    if ((pagenumber >= 0) && (pagenumber < xobjs.pages - 1) &&
-	    (thisinst != NULL)) {
-      plabel = thisinst->thisobject->name;
+	    (xobjs.pagelist[pagenumber]->pageinst != NULL)) {
+      plabel = xobjs.pagelist[pagenumber]->pageinst->thisobject->name;
       pname = (char *)malloc(28 + strlen(plabel));
       sprintf(pname, "xcircuit::renamepage %d {%s}", pagenumber + 1, plabel);
       Tcl_Eval(xcinterp, pname);
@@ -1569,10 +1557,10 @@ void renamepage(short pagenumber)
    sprintf(bname, "Page %d", pagenumber + 1);
    button = XtNameToWidget(parent, bname);
 
-   if ((button != NULL) && (thisinst != NULL)) {
-      if (thisinst->thisobject->name != NULL)
+   if ((button != NULL) && (xobjs.pagelist[pagenumber]->pageinst != NULL)) {
+      if (xobjs.pagelist[pagenumber]->pageinst->thisobject->name != NULL)
          XtSetArg(wargs[0], XtNlabel,
-		thisinst->thisobject->name);
+		xobjs.pagelist[pagenumber]->pageinst->thisobject->name);
       else
          XtSetArg(wargs[0], XtNlabel, bname);
       XtSetValues(button, wargs, 1);
@@ -1580,34 +1568,6 @@ void renamepage(short pagenumber)
    else if (button == NULL)
       Fprintf(stderr, "Error:  No Button Widget named \"%9s\"\n", bname);
 #endif
-
-   /* If the page had a master but now has a different	*/
-   /* name, disconnect the schematics.			*/
-
-   if (thisinst->thisobject->schemtype == SECONDARY) {
-      if (strcmp(thisinst->thisobject->name, thisinst->thisobject->symschem->name)) {
-	 thisinst->thisobject->symschem = NULL;
-	 thisinst->thisobject->schemtype = PRIMARY;
-      }
-      Wprintf("Page disconnected from master schematic.");
-   }
-
-   /* Conversely, if the page has the same name as another page, the	*/
-   /* schematics are considered connected.				*/
-
-   for (page = 0; page < xobjs.pages; page++) {
-      objinstptr pageinst;
-      if (page == pagenumber) continue;
-      pageinst = xobjs.pagelist[page]->pageinst;
-      if (pageinst && !strcmp(pageinst->thisobject->name,
-		thisinst->thisobject->name)) {
-	 thisinst->thisobject->symschem = pageinst->thisobject;
-	 thisinst->thisobject->schemtype = SECONDARY;
-         Wprintf("Page connected to master schematic.");
-	 break;
-      }
-   }
-
 }
 
 /*--------------------------------------------------------------*/
@@ -1687,22 +1647,21 @@ void setcolormark(int colorval)
    /* Set GUI variables and execute any command tags associated */
    /* with the "color" command */
 
-   Tcl_Obj *objv[3];
+   Tcl_Obj *objv[2];
    int i;
 
    objv[0] = Tcl_NewStringObj("color", 5);
-   objv[1] = Tcl_NewStringObj("set", 3);
    if (colorval == DEFAULTCOLOR)
-      objv[2] = Tcl_NewStringObj("inherit", 7);
+      objv[1] = Tcl_NewStringObj("inherit", 7);
    else {
       for (i = 0; i < number_colors; i++)
          if (colorlist[i].color.pixel == colorval)
 	    break;
-      objv[2] = Tcl_NewIntObj((int)i);
+      objv[1] = Tcl_NewIntObj((int)i);
    }
-   Tcl_SetVar2Ex(xcinterp, "XCOps", "colorval", objv[2], TCL_NAMESPACE_ONLY);
+   Tcl_SetVar2Ex(xcinterp, "colorval", NULL, objv[1], TCL_NAMESPACE_ONLY);
 
-   XcTagCallback(xcinterp, 3, objv);
+   XcTagCallback(xcinterp, 2, objv);
 #endif
 }
 
@@ -1779,13 +1738,13 @@ void setallstylemarks(u_short styleval)
    else
       objv[1] = Tcl_NewStringObj("unfilled", 8);
 
-   Tcl_SetVar2Ex(xcinterp, "XCOps", "fillamount", objv[1], TCL_NAMESPACE_ONLY);
-   Tcl_SetVar2(xcinterp, "XCOps", "opaque", (styleval & OPAQUE) ? "true" : "false",
+   Tcl_SetVar2Ex(xcinterp, "fillamount", NULL, objv[1], TCL_NAMESPACE_ONLY);
+   Tcl_SetVar(xcinterp, "opaque", (styleval & OPAQUE) ? "true" : "false",
 		TCL_NAMESPACE_ONLY);
-   Tcl_SetVar2(xcinterp, "XCOps", "bboxtype", (styleval & BBOX) ? "true" : "false",
+   Tcl_SetVar(xcinterp, "bboxtype", (styleval & BBOX) ? "true" : "false",
+		TCL_NAMESPACE_ONLY);
+   Tcl_SetVar(xcinterp, "polyclosed", (styleval & UNCLOSED) ? "false" : "true",
 		TCL_NAMESPACE_ONLY);
-   Tcl_SetVar2(xcinterp, "XCOps", "polyclosed", (styleval & UNCLOSED) ? "false" :
-		"true", TCL_NAMESPACE_ONLY);
 
    switch (styleval & BORDERS) {
       case DASHED:
@@ -1801,7 +1760,7 @@ void setallstylemarks(u_short styleval)
 	 bptr = borders[SolidIdx];
 	 break;
    }
-   Tcl_SetVar2(xcinterp, "XCOps", "linestyle", (char *)bptr, TCL_NAMESPACE_ONLY);
+   Tcl_SetVar(xcinterp, "linestyle", (char *)bptr, TCL_NAMESPACE_ONLY);
 
    XcTagCallback(xcinterp, 2, objv);
 
@@ -2103,14 +2062,13 @@ void addnewcolor(xcWidget w, caddr_t clientdata, caddr_t calldata)
 void togglestylemark(int styleval)
 {
    switch(styleval) {
-      case 0: Tcl_SetVar2(xcinterp, "XCOps", "fontstyle", "normal", TCL_NAMESPACE_ONLY);
+      case 0: Tcl_SetVar(xcinterp, "fontstyle", "normal", TCL_NAMESPACE_ONLY);
 	 break;
-      case 1: Tcl_SetVar2(xcinterp, "XCOps", "fontstyle", "bold", TCL_NAMESPACE_ONLY);
+      case 1: Tcl_SetVar(xcinterp, "fontstyle", "bold", TCL_NAMESPACE_ONLY);
 	 break;
-      case 2: Tcl_SetVar2(xcinterp, "XCOps", "fontstyle", "italic", TCL_NAMESPACE_ONLY);
+      case 2: Tcl_SetVar(xcinterp, "fontstyle", "italic", TCL_NAMESPACE_ONLY);
 	 break;
-      case 3: Tcl_SetVar2(xcinterp, "XCOps", "fontstyle", "bolditalic",
-		TCL_NAMESPACE_ONLY);
+      case 3: Tcl_SetVar(xcinterp, "fontstyle", "bolditalic", TCL_NAMESPACE_ONLY);
 	 break;
    }
 }
@@ -2120,29 +2078,21 @@ void togglestylemark(int styleval)
 void toggleencodingmark(int encodingval)
 {
    switch(encodingval) {
-      case 0: Tcl_SetVar2(xcinterp, "XCOps", "fontencoding", "Standard",
-		TCL_NAMESPACE_ONLY);
+      case 0: Tcl_SetVar(xcinterp, "fontencoding", "Standard", TCL_NAMESPACE_ONLY);
 	 break;
-      case 1: Tcl_SetVar2(xcinterp, "XCOps", "fontencoding", "special",
-		TCL_NAMESPACE_ONLY);
+      case 1: Tcl_SetVar(xcinterp, "fontencoding", "special", TCL_NAMESPACE_ONLY);
 	 break;
-      case 2: Tcl_SetVar2(xcinterp, "XCOps", "fontencoding", "ISOLatin1",
-		TCL_NAMESPACE_ONLY);
+      case 2: Tcl_SetVar(xcinterp, "fontencoding", "ISOLatin1", TCL_NAMESPACE_ONLY);
 	 break;
-      case 3: Tcl_SetVar2(xcinterp, "XCOps", "fontencoding", "ISOLatin2",
-		TCL_NAMESPACE_ONLY);
+      case 3: Tcl_SetVar(xcinterp, "fontencoding", "ISOLatin2", TCL_NAMESPACE_ONLY);
 	 break;
-      case 4: Tcl_SetVar2(xcinterp, "XCOps", "fontencoding", "ISOLatin3",
-		TCL_NAMESPACE_ONLY);
+      case 4: Tcl_SetVar(xcinterp, "fontencoding", "ISOLatin3", TCL_NAMESPACE_ONLY);
 	 break;
-      case 5: Tcl_SetVar2(xcinterp, "XCOps", "fontencoding", "ISOLatin4",
-		TCL_NAMESPACE_ONLY);
+      case 5: Tcl_SetVar(xcinterp, "fontencoding", "ISOLatin4", TCL_NAMESPACE_ONLY);
 	 break;
-      case 6: Tcl_SetVar2(xcinterp, "XCOps", "fontencoding", "ISOLatin5",
-		TCL_NAMESPACE_ONLY);
+      case 6: Tcl_SetVar(xcinterp, "fontencoding", "ISOLatin5", TCL_NAMESPACE_ONLY);
 	 break;
-      case 7: Tcl_SetVar2(xcinterp, "XCOps", "fontencoding", "ISOLatin6",
-		TCL_NAMESPACE_ONLY);
+      case 7: Tcl_SetVar(xcinterp, "fontencoding", "ISOLatin6", TCL_NAMESPACE_ONLY);
 	 break;
    }
 }
@@ -2151,40 +2101,32 @@ void toggleencodingmark(int encodingval)
 
 void togglejustmarks(int justvalue)
 {
-   switch(justvalue & RLJUSTFIELD) {
-      case NORMAL: Tcl_SetVar2(xcinterp, "XCOps", "jhoriz", "left",
-		TCL_NAMESPACE_ONLY);
+   switch(justvalue & (NOTLEFT | RIGHT)) {
+      case NORMAL: Tcl_SetVar(xcinterp, "jhoriz", "left", TCL_NAMESPACE_ONLY);
 	 break;
-      case NOTLEFT: Tcl_SetVar2(xcinterp, "XCOps", "jhoriz", "center",
-		TCL_NAMESPACE_ONLY);
+      case NOTLEFT: Tcl_SetVar(xcinterp, "jhoriz", "center", TCL_NAMESPACE_ONLY);
 	 break;
-      case RIGHT|NOTLEFT: Tcl_SetVar2(xcinterp, "XCOps", "jhoriz", "right",
-		TCL_NAMESPACE_ONLY);
+      case RIGHT|NOTLEFT: Tcl_SetVar(xcinterp, "jhoriz", "right", TCL_NAMESPACE_ONLY);
 	 break;
    }
-   switch(justvalue & TBJUSTFIELD) {
-      case NORMAL: Tcl_SetVar2(xcinterp, "XCOps", "jvert", "bottom",
-		TCL_NAMESPACE_ONLY);
+   switch(justvalue & (NOTBOTTOM | TOP)) {
+      case NORMAL: Tcl_SetVar(xcinterp, "jvert", "bottom", TCL_NAMESPACE_ONLY);
 	 break;
-      case NOTBOTTOM: Tcl_SetVar2(xcinterp, "XCOps", "jvert", "middle",
-		TCL_NAMESPACE_ONLY);
+      case NOTBOTTOM: Tcl_SetVar(xcinterp, "jvert", "middle", TCL_NAMESPACE_ONLY);
 	 break;
-      case TOP|NOTBOTTOM: Tcl_SetVar2(xcinterp, "XCOps", "jvert", "top",
-		TCL_NAMESPACE_ONLY);
+      case TOP|NOTBOTTOM: Tcl_SetVar(xcinterp, "jvert", "top", TCL_NAMESPACE_ONLY);
 	 break;
    }
 
    /* Flip Invariance property */
-   Tcl_SetVar2(xcinterp, "XCOps", "flipinvariant", (justvalue & FLIPINV) ?
-		"true" : "false", TCL_NAMESPACE_ONLY);
-
-   /* LaTeX mode property */
-   Tcl_SetVar2(xcinterp, "XCOps", "latexmode", (justvalue & LATEXLABEL) ?
-		"true" : "false", TCL_NAMESPACE_ONLY);
+   Tcl_SetVar(xcinterp, "flipinvariant", (justvalue & FLIPINV) ? "true" : "false",
+	TCL_NAMESPACE_ONLY);
      
+#ifdef SCHEMA
    /* Pin visibility property */
-   Tcl_SetVar2(xcinterp, "XCOps", "pinvisible", (justvalue & PINVISIBLE) ?
-		"true" : "false", TCL_NAMESPACE_ONLY);
+   Tcl_SetVar(xcinterp, "pinvisible", (justvalue & PINVISIBLE) ? "true" : "false",
+	TCL_NAMESPACE_ONLY);
+#endif
 }
 
 /*------------------------------------------------------*/
@@ -2229,14 +2171,14 @@ void setfontmarks(short fvalue, short jvalue)
       togglefontmark(fvalue);
    }
    if (jvalue >= 0) {
-      switch(jvalue & (RLJUSTFIELD)) {
+      switch(jvalue & (NOTLEFT | RIGHT)) {
          case NORMAL: w = JustificationLeftJustifiedButton; break;
          case NOTLEFT: w = JustificationCenterJustifiedButton; break;
          case RIGHT|NOTLEFT: w = JustificationRightJustifiedButton; break;
       }
       toggleexcl(w, Justifs, XtNumber(Justifs));
 
-      switch(jvalue & (TBJUSTFIELD)) {
+      switch(jvalue & (NOTBOTTOM | TOP)) {
          case NORMAL: w = JustificationBottomJustifiedButton; break;
          case NOTBOTTOM: w = JustificationMiddleJustifiedButton; break;
          case TOP|NOTBOTTOM: w = JustificationTopJustifiedButton; break;
@@ -2252,6 +2194,7 @@ void setfontmarks(short fvalue, short jvalue)
          XtSetArg(wargs[0], XtNsetMark, False);
       XtSetValues(w, wargs, 1);
 
+#ifdef SCHEMA
       /* Pin visibility property */
       w = NetlistPinVisibilityButton;
       if (jvalue & PINVISIBLE)
@@ -2259,74 +2202,43 @@ void setfontmarks(short fvalue, short jvalue)
       else
          XtSetArg(wargs[0], XtNsetMark, False);
       XtSetValues(w, wargs, 1);
+#endif
    }
 }
 
-/*----------------------------------------------*/
-/* GUI wrapper for startparam()			*/
-/*----------------------------------------------*/
-
-void promptparam(xcWidget w, caddr_t clientdata, caddr_t calldata)
-{
-   buttonsave *popdata = (buttonsave *)malloc(sizeof(buttonsave));
-
-   if (areastruct.selects == 0) return;  /* nothing was selected */
-
-   /* Get a name for the new object */
-
-   eventmode = NORMAL_MODE;
-   popdata->dataptr = NULL;
-   popdata->button = NULL; /* indicates that no button is assc'd w/ the popup */
-   popupprompt(w, "Enter name for new parameter:", "\0", stringparam, popdata, NULL);
-}
-
 #endif /* !TCL_WRAPPER */
 
 /*--------------------------------------------------------------*/
 /* Parameterize a label string (wrapper for parameterize()).	*/
-/* Assumes that the name has been generated by the popup prompt	*/
-/* and is therefore held in variable _STR2			*/
-/*--------------------------------------------------------------*/
-
-void stringparam(xcWidget w, caddr_t clientdata, caddr_t calldata)
-{
-   genericptr *settext;
-
-      if (eventmode == TEXT2_MODE || eventmode == TEXT3_MODE) {
-         settext = (genericptr *)EDITPART;
-         makeparam(TOLABEL(settext), _STR2);
-         objectdeselect();
-	 setparammarks(NULL);
-      }
-      else if (checkselect(LABEL)) parameterize(P_SUBSTRING, _STR2);
-      else
-         eventmode = LPARAM_MODE;
-}
-
-/*--------------------------------------------------------------*/
-/* Numerical parameterization (wrapper for parameterize()).	*/
 /*--------------------------------------------------------------*/
 
 void startparam(xcWidget w, pointertype value, caddr_t calldata)
 {
    genericptr *settext;
 
-   if (value == (pointertype)P_SUBSTRING) {
-      strcpy(_STR2, (calldata != NULL) ? (char *)calldata : "substring");
-      stringparam(w, NULL, NULL);
+   if (value == P_SUBSTRING) {
+      if (eventmode == TEXT2_MODE || eventmode == TEXT3_MODE) {
+         settext = (genericptr *)EDITPART;
+         makeparam(TOLABEL(settext));
+         objectdeselect();
+	 setparammarks(NULL);
+      }
+      else if (checkselect(LABEL)) parameterize((int)value);
+      else
+         eventmode = LPARAM_MODE;
    }
    else {
       if ((eventmode == NORMAL_MODE) && (areastruct.selects == 0)) { 
          eventmode = IPARAM_MODE;
          Wprintf("Click on object to parameterize.");
       }      
-      else parameterize((int)value, (char *)calldata);
+      else parameterize((int)value);
    }
 }
 
-/*---------------------------------------------------------------*/
-/* Unparameterize a label string (wrapper for unparameterize()). */
-/*---------------------------------------------------------------*/
+/*--------------------------------------------------------------*/
+/* Unparameterize a label string (wrapper for parameterize()).	*/
+/*--------------------------------------------------------------*/
 
 void startunparam(xcWidget w, pointertype value, caddr_t calldata)
 {
@@ -2352,55 +2264,55 @@ void setdefaultfontmarks()
    setfontmarks(areastruct.psfont, areastruct.justify);
 }
 
-/*--------------------------------------------------------------*/
-/* Toggle a bit in the justification field of a label		*/
-/*--------------------------------------------------------------*/
+/*----------------------------------------------------------------*/
+/* Change flip invariance on the label passed as 2nd parameter	  */
+/*----------------------------------------------------------------*/
 
-void dojustifybit(xcWidget w, labelptr settext, short bitfield)
+void doflipflip(xcWidget w, labelptr settext)
 {
+   short newjust;
+   Boolean boolval;
+   u_short value;
+
    if (settext != NULL) {
+      boolval = (settext->justify & FLIPINV) ? True : False;
+      value = boolval ? 0 : FLIPINV;
+      newjust = (settext->justify & (~FLIPINV)) | value;
+
       undrawtext(settext);
-      settext->justify ^= bitfield;
+      settext->justify = newjust;
       redrawtext(settext);
       pwriteback(areastruct.topinstance);
    }
-   else
-      areastruct.justify ^= bitfield;
-
-#ifndef TCL_WRAPPER
-   if (w != NULL) {
-      Boolean boolval;
-      if (settext)
-	 boolval = (settext->justify & bitfield) ? 0 : 1;
-      else
-	 boolval = (areastruct.justify & bitfield) ? 0 : 1;
-      toggle(w, &boolval, NULL);
+   else {
+      boolval = (areastruct.justify & FLIPINV) ? True : False;
+      value = boolval ? 0 : FLIPINV;
+      newjust = (areastruct.justify & (~FLIPINV)) | value;
+      areastruct.justify = newjust;
    }
-#endif
+   if (w != NULL) toggle(w, &boolval, NULL);
 }
 
-/*--------------------------------------------------------------*/
-/* Toggle a pin-related bit in the justification field of a	*/
-/* label.  This differs from dojustifybit() in that the label	*/
-/* must be a pin, and this function cannot change the default	*/
-/* behavior set by areastruct.justify.				*/
-/*--------------------------------------------------------------*/
+/*----------------------------------------------------------------*/
+/* Change pin visibility on the label passed as 2nd parameter	  */
+/*----------------------------------------------------------------*/
 
-void dopinjustbit(xcWidget w, labelptr settext, short bitfield)
+void dopinvisible(xcWidget w, labelptr settext)
 {
+   short newjust;
+   Boolean boolval;
+   u_short value;
+
+   if (settext != NULL && settext->pin) {
+      boolval = (settext->justify & PINVISIBLE) ? True : False;
+      value = boolval ? 0 : PINVISIBLE;
+      newjust = (settext->justify & (~PINVISIBLE)) | value;
 
-   if ((settext != NULL) && settext->pin) {
       undrawtext(settext);
-      settext->justify ^= bitfield;
+      settext->justify = newjust;
       redrawtext(settext);
       pwriteback(areastruct.topinstance);
-
-#ifndef TCL_WRAPPER
-      if (w != NULL) {
-	 Boolean boolval = (settext->justify & bitfield) ? 0 : 1;
-	 toggle(w, &boolval, NULL);
-      }
-#endif
+      if (w != NULL) toggle(w, &boolval, NULL);
    }
 }
 
@@ -2415,10 +2327,10 @@ void setjust(xcWidget w, pointertype value, labelptr settext, short mode)
    if (settext != NULL) {
 
       if (mode == 1)
-         newjust = (settext->justify & (NONJUSTFIELD | TBJUSTFIELD))
+         newjust = (settext->justify & (PINVISIBLE | FLIPINV | TOP | NOTBOTTOM))
 			| value;
       else
-         newjust = (settext->justify & (NONJUSTFIELD | RLJUSTFIELD))
+         newjust = (settext->justify & (PINVISIBLE | FLIPINV | RIGHT | NOTLEFT))
 			| value;
 
       undrawtext(settext);
@@ -2428,10 +2340,10 @@ void setjust(xcWidget w, pointertype value, labelptr settext, short mode)
    }
    else {
       if (mode == 1)
-         newjust = (areastruct.justify & (NONJUSTFIELD | TBJUSTFIELD))
+         newjust = (areastruct.justify & (PINVISIBLE | FLIPINV | TOP | NOTBOTTOM))
 			| value;
       else
-         newjust = (areastruct.justify & (NONJUSTFIELD | RLJUSTFIELD))
+         newjust = (areastruct.justify & (PINVISIBLE | FLIPINV | RIGHT | NOTLEFT))
 			| value;
       areastruct.justify = newjust;
    }
@@ -2498,12 +2410,11 @@ void sethjust(xcWidget w, pointertype value, caddr_t nulldata)
    }
 }
 
-/*--------------------------------------------------------------*/
-/* Set a justify field bit on all selected labels		*/ 
-/* (flip invariance, latex mode, etc.)				*/
-/*--------------------------------------------------------------*/
+/*----------------------------------------------------------------*/
+/* Set flip invariance on all selected labels			  */ 
+/*----------------------------------------------------------------*/
 
-void setjustbit(xcWidget w, pointertype value, caddr_t nulldata)
+void setflipinv(xcWidget w, pointertype value, caddr_t nulldata)
 {
    short *fselect;
    labelptr settext;
@@ -2511,7 +2422,7 @@ void setjustbit(xcWidget w, pointertype value, caddr_t nulldata)
 
    if (eventmode == TEXT2_MODE || eventmode == TEXT3_MODE) {
       settext = *((labelptr *)EDITPART);
-      dojustifybit(w, settext, (short)value);
+      doflipflip(w, settext);
    }
    else {
       for (fselect = areastruct.selectlist; fselect < areastruct.selectlist +
@@ -2519,36 +2430,37 @@ void setjustbit(xcWidget w, pointertype value, caddr_t nulldata)
          if (SELECTTYPE(fselect) == LABEL) {
             labelcount++;
             settext = SELTOLABEL(fselect);
-            dojustifybit(NULL, settext, (short)value);
+            doflipflip(NULL, settext);
          }
       }
-      if (labelcount == 0) dojustifybit(w, NULL, (short)value);
+      if (labelcount == 0) doflipflip(w, NULL);
       else objectdeselect();
    }
 }
 
-/*--------------------------------------------------------------*/
-/* Set pin-related bit field of "justify" on all selected pins	*/ 
-/* (e.g., pin visibility)					*/
-/*--------------------------------------------------------------*/
+/*----------------------------------------------------------------*/
+/* Set pin visibility on all selected pins			  */ 
+/*----------------------------------------------------------------*/
 
-void setpinjustbit(xcWidget w, pointertype value, caddr_t nulldata)
+void setpinvisible(xcWidget w, pointertype value, caddr_t nulldata)
 {
    short *fselect;
    labelptr settext;
+   short labelcount = 0;
 
    if (eventmode == TEXT2_MODE || eventmode == TEXT3_MODE) {
       settext = *((labelptr *)EDITPART);
       if (settext->pin)
-	 dopinjustbit(w, settext, (short)value);
+	 dopinvisible(w, settext);
    }
    else {
       for (fselect = areastruct.selectlist; fselect < areastruct.selectlist +
             areastruct.selects; fselect++) {
          if (SELECTTYPE(fselect) == LABEL) {
+            labelcount++;
             settext = SELTOLABEL(fselect);
 	    if (settext->pin)
-               dopinjustbit(NULL, settext, (short)value);
+               dopinvisible(NULL, settext);
          }
       }
       objectdeselect();
@@ -2565,19 +2477,19 @@ void boxedit(xcWidget w, pointertype value, caddr_t nulldata)
 {
    switch (value) {
       case MANHATTAN:
-	 Tcl_SetVar2(xcinterp, "XCOps", "polyedittype", "manhattan", TCL_NAMESPACE_ONLY);
+	 Tcl_SetVar(xcinterp, "polyedittype", "manhattan", TCL_NAMESPACE_ONLY);
 	 break;
       case RHOMBOIDX:
-	 Tcl_SetVar2(xcinterp, "XCOps", "polyedittype", "rhomboidx", TCL_NAMESPACE_ONLY);
+	 Tcl_SetVar(xcinterp, "polyedittype", "rhomboidx", TCL_NAMESPACE_ONLY);
 	 break;
       case RHOMBOIDY:
-	 Tcl_SetVar2(xcinterp, "XCOps", "polyedittype", "rhomboidy", TCL_NAMESPACE_ONLY);
+	 Tcl_SetVar(xcinterp, "polyedittype", "rhomboidy", TCL_NAMESPACE_ONLY);
 	 break;
       case RHOMBOIDA:
-	 Tcl_SetVar2(xcinterp, "XCOps", "polyedittype", "rhomboida", TCL_NAMESPACE_ONLY);
+	 Tcl_SetVar(xcinterp, "polyedittype", "rhomboida", TCL_NAMESPACE_ONLY);
 	 break;
       case NORMAL:
-	 Tcl_SetVar2(xcinterp, "XCOps", "polyedittype", "normal", TCL_NAMESPACE_ONLY);
+	 Tcl_SetVar(xcinterp, "polyedittype", "normal", TCL_NAMESPACE_ONLY);
 	 break;
    }
 
@@ -3014,25 +2926,17 @@ void fontencoding(xcWidget w, pointertype value, caddr_t nulldata)
 
 /*----------------------------------------------*/
 /* Generate the table of special characters	*/
-/*						*/
-/* Return FALSE if the edited label is LaTeX-	*/
-/* compatible, since LaTeX text does not	*/
-/* usually contain special characters, but it	*/
-/* does contain a lot of backslashes.		*/
 /*----------------------------------------------*/
 
-Boolean dospecial()
+void dospecial()
 {
    labelptr curlabel;
    int cfont;
 
    curlabel = TOLABEL(EDITPART);
-   if (curlabel->justify & LATEXLABEL) return False;
-
    cfont = findcurfont(textpos, curlabel->string, areastruct.topinstance);
    composefontlib(cfont);
    startcatalog(NULL, FONTLIB, NULL);
-   return True;
 }
 
 /*-------------------------------------------------*/
