@@ -36,11 +36,6 @@ typedef unsigned long	u_long;
 #define sign(a)			((a) <= 0 ? -1 : 1)
 #define max(a,b)		((a) < (b) ? (b) : (a))
 #define min(a,b)		((a) < (b) ? (a) : (b))
-
-/*----------------------------------------------------------------------*/
-/* Deal with 32/64 bit processors based on autoconf results.		*/
-/*----------------------------------------------------------------------*/
-
 #if SIZEOF_VOID_P == SIZEOF_UNSIGNED_INT
 #define Number(a)		(void *)((u_int) a)
 typedef u_int pointertype;
@@ -156,7 +151,10 @@ typedef struct {
 #define MINAUTOSCALE 0.75 /* Won't automatically scale closer than this */
 #define MAXCHANGES 20 /* Number of changes to induce a temp file save	*/
 #define STIPPLES    8 /* Number of predefined stipple patterns		*/
+
+#ifdef SCHEMA
 #define PADSPACE   10 /* Spacing of pinlabels from their origins	*/
+#endif
 
 #ifdef HAVE_XPM
 #define TBBORDER   1  /* border around toolbar buttons */
@@ -200,18 +198,24 @@ CATPAN_MODE, CATALOG_MODE, CATTEXT_MODE, FONTCAT_MODE, FONTCAT2_MODE,
 TEXT1_MODE, TEXT2_MODE, TEXT3_MODE, WIRE_MODE, POLY_MODE, BOX0_MODE,
 BOX_MODE, EBOX_MODE, ARC0_MODE, ARC_MODE, EARC_MODE, SPLINE0_MODE,
 SPLINE_MODE, ESPLINE_MODE, EPATH_MODE, LPARAM_MODE, IPARAM_MODE,
-ULPARAM_MODE, UIPARAM_MODE, CONNECT_MODE, ASSOC_MODE};
+ULPARAM_MODE, UIPARAM_MODE
+
+#ifdef SCHEMA
+, CONNECT_MODE, ASSOC_MODE
+#endif
+
+};
 
 /*----------------------------------------------------------------------*/
 /* File loading modes							*/
 /*----------------------------------------------------------------------*/
 
-#define LOAD_MODES 5
-
-#define IMPORT     1
-#define PSBKGROUND 2
-#define SCRIPT	   3
-#define RECOVER    4
+enum loadmodes {IMPORT = 1, PSBKGROUND, SCRIPT, RECOVER,
+#ifdef ASG
+	IMPORTIVF, IMPORTSPICE,
+#endif
+	LOAD_MODES
+};
 
 /*----------------------------------------------------------------------*/
 /* Text justification styles and other parameters (bitmask)		*/
@@ -221,14 +225,9 @@ ULPARAM_MODE, UIPARAM_MODE, CONNECT_MODE, ASSOC_MODE};
 #define RIGHT		2
 #define NOTBOTTOM	4
 #define TOP		8
-#define FLIPINV		16	/* 1 if text is flip-invariant		*/
-#define PINVISIBLE	32	/* 1 if pin visible outside of object	*/
-#define PINNOOFFSET	64	/* 0 if pin label offset from position	*/
-#define LATEXLABEL	128
-
-#define RLJUSTFIELD	3	/* right-left justification bit field	*/
-#define TBJUSTFIELD	12	/* top-bottom justification bit field	*/
-#define NONJUSTFIELD	240	/* everything but justification fields	*/
+#define FLIPINV		16	/* 1 if text is flip-invariant */
+#define PINVISIBLE	32	/* 1 if pin visible outside of object */
+#define PINNOOFFSET	64	/* 0 if pin label offset from position */
 
 /*----------------------------------------------------------------------*/
 /* Text string part: types						*/
@@ -332,11 +331,12 @@ ULPARAM_MODE, UIPARAM_MODE, CONNECT_MODE, ASSOC_MODE};
 /* Schematic object types and pin label types	   			*/
 /*----------------------------------------------------------------------*/
 
-#define PRIMARY 0		/* Primary (master) schematic page */
-#define SECONDARY 1		/* Secondary (slave) schematic page */
-#define TRIVIAL 2		/* Symbol as non-schematic element */
-#define SYMBOL 3		/* Symbol associated with a schematic */
-#define FUNDAMENTAL 4		/* Standalone symbol */
+#ifdef SCHEMA
+
+#define SCHEMATIC 0		/* Schematic on page */
+#define TRIVIAL 1		/* Symbol as non-schematic element */
+#define SYMBOL 2		/* Symbol associated with a schematic */
+#define FUNDAMENTAL 3		/* Standalone symbol */
 
 #define LOCAL 1
 #define GLOBAL 2
@@ -344,6 +344,8 @@ ULPARAM_MODE, UIPARAM_MODE, CONNECT_MODE, ASSOC_MODE};
 
 #define HIERARCHY_LIMIT 256	/* Stop if recursion goes this deep */
 
+#endif
+
 /*----------------------------------------------------------------------*/
 /* Save types.	This list incorporates "ALL_PAGES", below.		*/
 /*----------------------------------------------------------------------*/
@@ -403,13 +405,11 @@ typedef XfPoint* fpointlist;
 #define PATH	32
 #define SEL_ANY	63  /* for selection mechanism only */
 
-#define REMOVE_TAG 64  /* add this value to objects to be removed */
-
 /*----------------------------------------------------------------------*/
 /* Allowed parameterization types					*/
 /*----------------------------------------------------------------------*/
 
-#define P_NUMERIC	0	/* uncommitted numeric parameter */
+#define P_POSITION	0	/* mode only, not a real parameter */
 #define P_SUBSTRING	1
 #define P_POSITION_X	2
 #define P_POSITION_Y	3
@@ -423,8 +423,6 @@ typedef XfPoint* fpointlist;
 #define P_SCALE		11
 #define P_LINEWIDTH	12
 #define P_COLOR		13
-#define P_EXPRESSION	14
-#define P_POSITION	15	/* mode only, not a real parameter */
 
 /*----------------------------------------------------------------------*/
 /* Labels are constructed of strings and executables 			*/
@@ -439,6 +437,7 @@ typedef struct _stringpart {
      u_char	*string;
      int	color;
      int	font;
+     int	paramno;
      float	scale;
      short	kern[2];
    }		data;
@@ -453,41 +452,22 @@ typedef struct _stringpart {
 /* (Add types as necessary)						*/
 /*----------------------------------------------------------------------*/
 
-enum paramtypes {XC_INT = 0, XC_FLOAT, XC_STRING, XC_EXPR};
+enum paramtypes {XC_INT = 0, XC_FLOAT, XC_STRING};
 
-/* Object parameters: general key:value parameter model */
-/* Note that this really should be a hash table, not a linked list. . . */
-
-typedef struct _oparam *oparamptr;
-
-typedef struct _oparam {
-   char *	key;		/* name of the parameter */
+typedef struct {
    u_char	type;		/* type is from paramtypes list above */
    u_char	which;		/* what the parameter represents (P_*) */
    union {
-      stringpart *string;	/* xcircuit label type */
-      char	 *expr;		/* TCL (string) expression */
+      stringpart *string;
       int	  ivalue;	/* also covers type short int by typecasting */
       float	  fvalue;
    } parameter;			/* default or substitution value */
-   oparamptr	next;		/* next parameter in linked list */
-} oparam;
+} oparam, *oparamptr;
 
-/* Element parameters: reference back to the object's parameters */
-/* These parameters are forward-substituted when descending into */
-/* an object instance.						 */
-/* Note that this really should be a hash table, not a linked list. . . */
-
-typedef struct _eparam *eparamptr;
-
-typedef struct _eparam {
-   char *	key;	    /* name of the parameter */
-   union {
-      int	pointno;    /* point number in point array, for polygons */
-      char	*refkey;    /* parameter reference key, for instances */
-   } pdata;
-   eparamptr	next;	    /* next parameter in linked list */
-} eparam;
+typedef struct {
+   u_char	paramno;	/* parameter number to get value from.	   */
+   u_char	pointno;	/* point number in point array, for polygons */
+} eparam, *eparamptr;
 
 /*----------------------------------------------------------------------*/
 /* Generic element type	is a superset of all elements.			*/	
@@ -497,6 +477,7 @@ typedef struct {
    u_char	type;		/* type is LABEL, POLYGON, etc., from below */
    int		color;
    eparamptr	passed;
+   u_char	num_params;
 } generic, *genericptr;		/* (convenience function for retypecasting) */
 
 /*----------------------------------------------------------------------*/
@@ -518,13 +499,16 @@ typedef struct {
    u_char	type;
    int		color;
    eparamptr	passed;		/* numerical parameters passed from above */
+   u_char	num_params;
    XPoint	position;
    short	rotation;
    float	scale;
    objectptr	thisobject;
-   oparamptr	params;		/* parameter substitutions for this instance */
+   oparamptr    *params;	/* parameter substitutions for this instance */
    BBox		bbox;		/* per-instance bounding box information */
+#ifdef SCHEMA
    BBox		*schembbox;	/* Extra bounding box for pin labels */
+#endif
 } objinst, *objinstptr;
 
 /* Linked-list for objects */
@@ -565,11 +549,14 @@ typedef struct {
    u_char	type;
    int		color;
    eparamptr	passed;		/* numerical parameters passed from above */
+   u_char	num_params;
    XPoint	position;
    short	rotation;
    float	scale;
    short	justify;
+#ifdef SCHEMA
    u_char	pin;
+#endif
    stringpart	*string;
 } label, *labelptr;
 
@@ -581,6 +568,7 @@ typedef struct {
    u_char	type;
    int		color;
    eparamptr	passed;		/* numerical parameters passed from above */
+   u_char	num_params;
    u_short	style;
    float	width;
    short	number;
@@ -595,6 +583,7 @@ typedef struct {
    u_char	type;
    int		color;
    eparamptr	passed;		/* numerical parameters passed from above */
+   u_char	num_params;
    u_short	style;
    float	width;
    XPoint	ctrl[4];
@@ -610,6 +599,7 @@ typedef struct {
    u_char	type;
    int		color;
    eparamptr	passed;		/* numerical parameters passed from above */
+   u_char	num_params;
    u_short	style;
    float	width;
    short	radius; 	/* x-axis radius */
@@ -630,6 +620,7 @@ typedef struct {
    u_char	type;
    int		color;
    eparamptr	passed;		/* numerical parameters passed from above */
+   u_char	num_params;
    u_short	style;
    float	width;
    short	parts;
@@ -640,14 +631,15 @@ typedef struct {
 /* Netlist structures for schematic capture				*/
 /*----------------------------------------------------------------------*/
 
+#ifdef SCHEMA
+
 /* Linked polygon list */
 
 typedef struct _Polylist *PolylistPtr;
 typedef struct _Polylist
 {
-   objectptr cschem;	/* Schematic containing the polygon */
    polyptr poly;
-   PolylistPtr next;	/* Next polygon in the linked list */
+   PolylistPtr next;
 } Polylist;
 
 /* Linked label list */
@@ -655,7 +647,6 @@ typedef struct _Polylist
 typedef struct _Labellist *LabellistPtr;
 typedef struct _Labellist
 {
-   objectptr cschem;	/* Schematic containing the label */
    labelptr label;
    LabellistPtr next;
 } Labellist;
@@ -688,9 +679,8 @@ typedef struct _Portlist
 typedef struct _Calllist *CalllistPtr;
 typedef struct _Calllist
 {
-   objectptr   cschem;		/* Schematic page containing the instance */
-   objinstptr  callinst;	/* Instance called */
-   objectptr   callobj;		/* Object of instance called */
+   objectptr   callobj;
+   objinstptr  callinst;
    int         devindex;	/* if non-zero, index of device in netlist */
    PortlistPtr ports;
    CalllistPtr next;
@@ -710,7 +700,6 @@ struct Pstr {
 };
 
 struct Ptab {
-   objectptr cschem;
    struct Pnet *nets;
    struct Pstr *pins;
    struct Ptab *next;
@@ -725,6 +714,8 @@ typedef struct {
    objinstptr	thisinst;
 } Highlight;
 
+#endif
+
 /*----------------------------------------------------------------------*/
 /* Main object structure						*/
 /*----------------------------------------------------------------------*/
@@ -739,17 +730,21 @@ typedef struct _xcobject {
 				/* parameterized elements) */
    short	parts;
    genericptr	*plist;	 	/* to be retypecast to label, polygon, etc. */
-   oparamptr	params;		/* list of parameters, with default values */
+   u_char	num_params;	/* number of calling parameters */
+   oparamptr	*params;	/* list of parameter defaults */
    
+#ifdef SCHEMA
    Highlight	highlight;	/* net to be highlighted on redraw */
    u_char	schemtype;
    objectptr	symschem;	/* schematic page support */
+
    char		*devname;	/* if non-null, name of device in netlist */
    Boolean	valid;		/* Is current netlist valid? */
    Boolean	traversed;	/* Flag to indicate object was processed */
    NetlistPtr   netlist;
    PortlistPtr  portlist;
    CalllistPtr  calllist;
+#endif
 } object;
 
 /*----------------------------------------------------------------------*/
@@ -882,8 +877,10 @@ enum {DIRECTORY = 0, MATCH, NONMATCH};	/* file types */
 /*----------------------------------------------------------------------*/
 
 typedef struct {
+#ifdef SCHEMA
    /* schematic layout colors */
-   Pixel	globalcolor, localcolor, infocolor, ratsnestcolor;
+   Pixel	globalcolor, localcolor, infocolor;
+#endif
 
    /* non-schematic layout color(s) */
    Pixel	bboxpix;
@@ -902,12 +899,7 @@ typedef struct {
    Pixel	auxpix2, barpix2, parampix2;
 
    int		width, height, timeout;
-   XFontStruct	*helpfont, *filefont;
-
-#ifndef TCL_WRAPPER
-   XFontStruct	*xcfont, *textfont, *titlefont;
-#endif
-
+   XFontStruct	*xcfont, *helpfont, *filefont, *textfont, *titlefont;
 } ApplicationData, *ApplicationDataPtr;
 
 /*----------------------------------------------------------------------*/
@@ -989,17 +981,16 @@ enum {
    XCF_ENDDATA = -2, XCF_SPACER,
    XCF_Page, XCF_Justify, XCF_Superscript, XCF_Subscript, XCF_Normalscript,
    XCF_Nextfont, XCF_Boldfont, XCF_Italicfont, XCF_Normalfont, XCF_Underline,
-   XCF_Overline, XCF_ISO_Encoding, XCF_Halfspace, XCF_Quarterspace,
+   XCF_Overline, XCF_ISO_Encoding, XCF_Return, XCF_Halfspace, XCF_Quarterspace,
    XCF_Special, XCF_TabStop, XCF_TabForward, XCF_TabBackward,
    XCF_Text_Return, XCF_Text_Delete, XCF_Text_Right, XCF_Text_Left,
    XCF_Text_Up, XCF_Text_Down, XCF_Text_Split,
-   XCF_Text_Home, XCF_Text_End, XCF_Linebreak, XCF_Parameter,
-   XCF_Edit_Param,XCF_Edit_Break, XCF_Edit_Delete, XCF_Edit_Insert,
-   XCF_Edit_Append, XCF_Edit_Next, XCF_Attach,
-   XCF_Next_Library, XCF_Library_Directory,
+   XCF_Text_Home, XCF_Text_End, XCF_Return_Char, XCF_Parameter,
+   XCF_Edit_Param, XCF_Edit_Break, XCF_Edit_Delete, XCF_Edit_Insert,
+   XCF_Edit_Next, XCF_Attach, XCF_Next_Library, XCF_Library_Directory,
    XCF_Library_Move, XCF_Library_Copy, XCF_Library_Edit, XCF_Library_Delete,
    XCF_Library_Duplicate, XCF_Library_Hide, XCF_Library_Virtual,
-   XCF_Page_Directory, XCF_Library_Pop, XCF_Virtual,
+   XCF_Page_Directory, XCF_Library_Pop,
    XCF_Help, XCF_Redraw, XCF_View, XCF_Zoom_In, XCF_Zoom_Out, XCF_Pan,
    XCF_Double_Snap, XCF_Halve_Snap, XCF_Pan_Left, XCF_Pan_Right, XCF_Pan_Up,
    XCF_Pan_Down, XCF_Write, XCF_Rotate, XCF_Flip_X, XCF_Flip_Y, XCF_Snap,
@@ -1008,8 +999,11 @@ enum {
    XCF_Edit, XCF_Undelete, XCF_Select_Save, XCF_Unselect, XCF_Dashed,
    XCF_Dotted, XCF_Solid, XCF_Prompt, XCF_Dot, XCF_Wire, XCF_Start,
    XCF_Finish, XCF_Cancel, XCF_Nothing, XCF_Exit,
+
+#ifdef SCHEMA
    XCF_Netlist, XCF_Swap, XCF_Pin_Label, XCF_Pin_Global, XCF_Info_Label,
    XCF_Connectivity, XCF_Sim, XCF_SPICE, XCF_PCB, XCF_SPICEflat,
+#endif
    NUM_FUNCTIONS
 };
 
@@ -1074,8 +1068,10 @@ typedef struct {
    Boolean	mapped;		/* indicates if window is drawable */
    Boolean	filefilter;	/* Is the file list filtered? */
    Boolean	editinplace;
+#ifdef SCHEMA
    Boolean	schemon;
    Boolean	pinpointon;
+#endif
 #ifdef HAVE_XPM
    Boolean	toolbar_on;
 #endif
